@@ -58,7 +58,7 @@ public:
 	virtual void setVolume(int volume) = 0; // [0 - 200]
 	virtual void setAspectRatio(MediaWidget::AspectRatio aspectRatio) = 0;
 	virtual void resizeToVideo(float scale) = 0;
-	virtual void setDeinterlacing(bool deinterlacing) = 0;
+	virtual void setDeinterlacing(MediaWidget::DeinterlaceMode) = 0;
 	virtual void play(const MediaSource &source) = 0;
 	virtual void stop() = 0;
 	virtual void setPaused(bool paused) = 0;
@@ -72,6 +72,7 @@ public:
 	virtual bool jumpToPreviousChapter() = 0;
 	virtual bool jumpToNextChapter() = 0;
 	virtual void showDvdMenu() = 0;
+	virtual void dvdNavigate(int key) = 0;
 
 	enum PendingUpdate
 	{
@@ -145,7 +146,7 @@ public:
 	void setVolume(int) {}; // [0 - 200]
 	void setAspectRatio(MediaWidget::AspectRatio) {};
 	void resizeToVideo(float) {};
-	void setDeinterlacing(bool) {};
+	void setDeinterlacing(MediaWidget::DeinterlaceMode) {};
 	void play(const MediaSource &) {};
 	void stop() {};
 	void setPaused(bool) {};
@@ -159,6 +160,7 @@ public:
 	bool jumpToPreviousChapter() { return false; };
 	bool jumpToNextChapter() { return false; }
 	void showDvdMenu() {};
+	void dvdNavigate(int) {};
 
 	int updatePlaybackStatus() { return true; };
 	void updateCurrentTotalTime() {};
