@@ -113,10 +113,6 @@ const char *vlcEventName(int event)
 		return "MediaListPlayerNextItemSet";
 	case libvlc_MediaListPlayerStopped:
 		return "MediaListPlayerStopped";
-	case libvlc_RendererDiscovererItemAdded:
-		return "RendererDiscovererItemAdded";
-	case libvlc_RendererDiscovererItemDeleted:
-		return "RendererDiscovererItemDeleted";
 	case libvlc_VlmMediaAdded:
 		return "VlmMediaAdded";
 	case libvlc_VlmMediaRemoved:
@@ -140,6 +136,10 @@ const char *vlcEventName(int event)
 	case libvlc_VlmMediaInstanceStatusError:
 		return "VlmMediaInstanceStatusError";
 #if LIBVLC_VERSION_MAJOR > 2
+	case libvlc_RendererDiscovererItemAdded:
+		return "RendererDiscovererItemAdded";
+	case libvlc_RendererDiscovererItemDeleted:
+		return "RendererDiscovererItemDeleted";
 	case libvlc_MediaPlayerAudioVolume:
 		return "MediaPlayerAudioVolume";
 	case libvlc_MediaPlayerAudioDevice:
@@ -171,17 +171,17 @@ VlcMediaWidget::VlcMediaWidget(QWidget *parent) : AbstractMediaWidget(parent),
     typeOfDevice(""), trackNumber(1), numTracks(1)
 {
 	libvlc_event_e events[] = {
-		libvlc_MediaMetaChanged,
 		libvlc_MediaPlayerEncounteredError,
 		libvlc_MediaPlayerEndReached,
 		libvlc_MediaPlayerLengthChanged,
 		libvlc_MediaPlayerSeekableChanged,
 		libvlc_MediaPlayerStopped,
+		libvlc_MediaPlayerTimeChanged,
 #if LIBVLC_VERSION_MAJOR > 2
+		libvlc_MediaMetaChanged,
 		libvlc_MediaPlayerESAdded,
 		libvlc_MediaPlayerESDeleted,
 #endif
-		libvlc_MediaPlayerTimeChanged,
 #if 0 // all other possible events
 		libvlc_MediaSubItemAdded,
 		libvlc_MediaDurationChanged,
@@ -558,6 +558,13 @@ void VlcMediaWidget::unregisterEvents()
 	for (int i = 0; i < eventType.size(); ++i)
 		libvlc_event_detach(eventManager, eventType.at(i),
 				    vlcEventHandler, this);
+#if LIBVLC_VERSION_MAJOR <= 2
+	if (!vlcMedia)
+		return;
+	libvlc_event_manager_t *mediaEvent = libvlc_media_event_manager(vlcMedia);
+	libvlc_event_detach(mediaEvent, libvlc_MediaMetaChanged,
+			    vlcEventHandler, this);
+#endif
 }
 
 bool VlcMediaWidget::registerEvents()
@@ -578,6 +585,25 @@ int VlcMediaWidget::makePlay()
 		return -1;
 	}
 
+#if LIBVLC_VERSION_MAJOR <= 2
+	/*
+	 * There is a difference between libVlc 2.x and 3.x:
+	 * With version 2.x, the event needs to be registered at the
+	 * vlcMedia object, just before calling libvlc_media_player_set_media()
+	 *
+	 * On version 3.x, while this still works, you can simply register the
+	 * event directly at vlcMediaPlayer, together with all other events,
+	 * with simplifies the code.
+	 */
+	libvlc_event_manager_t *mediaEvent = libvlc_media_event_manager(vlcMedia);
+
+	if (libvlc_event_attach(mediaEvent, libvlc_MediaMetaChanged,
+				vlcEventHandler, this) != 0) {
+		qCWarning(logMediaWidget, "Cannot attach event handler %d",
+			  libvlc_MediaMetaChanged);
+	}
+#endif
+
 	libvlc_media_player_set_media(vlcMediaPlayer, vlcMedia);
 
 	/*
