@@ -33,8 +33,6 @@ class VlcMediaWidget : public AbstractMediaWidget
 private:
 	explicit VlcMediaWidget(QWidget *parent);
 	bool init();
-	QTimer *timer;
-	bool isPaused;
 
 private slots:
 	void hideMouse();
@@ -81,6 +79,8 @@ public:
 	void updateAngles();
 	void updateDvdMenu();
 	void updateVideoSize();
+	void unregisterEvents();
+	bool registerEvents();
 
 private:
 	void mousePressEvent(QMouseEvent *event);
@@ -90,15 +90,18 @@ private:
 
 	static void vlcEventHandler(const libvlc_event_t *event, void *instance);
 
+	QTimer *timer;
 	libvlc_instance_t *vlcInstance;
 	libvlc_media_t *vlcMedia;
 	libvlc_media_player_t *vlcMediaPlayer;
+	libvlc_event_manager_t *eventManager;
+	bool isPaused;
 	bool playingDvd;
-	bool mouseVisible;
+	bool urlIsAudioCd;
 	QMap<int, int> subtitleId;
 	QByteArray typeOfDevice;
-	bool urlIsAudioCd;
-	int trackNumber = 1, numTracks;
+	int trackNumber, numTracks;
+	QVector<libvlc_event_e> eventType;
 };
 
 #endif /* VLCMEDIAWIDGET_H */
