@@ -27,6 +27,16 @@ class AtscEpgFilter;
 class DvbDevice;
 class DvbEpgFilter;
 
+#define FIRST_LANG "first"
+
+class DvbEpgLangEntry
+{
+public:
+	QString title;
+	QString subheading;
+	QString details;
+};
+
 class DvbEpgEntry : public SharedData
 {
 public:
@@ -49,13 +59,146 @@ public:
 	EitType type;
 	QDateTime begin; // UTC
 	QTime duration;
-	QString title;
-	QString subheading;
-	QString details;
 	QString content;
 	QString parental;
+
+	// ISO 639-2 language-dependent entries
+	QHash<QString, DvbEpgLangEntry> langEntry;
+
 	DvbSharedRecording recording;
 
+	QString title(QString lang = QString()) const {
+		QString s;
+
+		if (!lang.isEmpty()) {
+			/*
+			 * Only return the user requested data
+			 * ISO-639-2 code if the title is filled.
+			 *
+			 * If it isn't, show first language
+			 */
+			if (langEntry[lang].title.isEmpty())
+				lang = FIRST_LANG;
+			else if (lang != FIRST_LANG)
+				return langEntry[lang].title;
+		}
+
+		QHashIterator<QString, DvbEpgLangEntry> i(langEntry);
+		bool first = true;
+
+		while (i.hasNext()) {
+			i.next();
+
+			QString code = i.key();
+			DvbEpgLangEntry entry = i.value();
+
+			if (!entry.title.isEmpty()) {
+				if (first)
+					first = false;
+				else
+					s += "/";
+
+				if (langEntry.size() > 1 && (lang != FIRST_LANG && code != FIRST_LANG)) {
+					s += code;
+					s += ": ";
+				}
+				s += entry.title;
+			}
+
+			if (lang == FIRST_LANG)
+				break;
+		}
+		return s;
+	}
+
+	QString subheading(QString lang = QString()) const {
+		QString s;
+
+		if (!lang.isEmpty()) {
+			/*
+			 * Only return the user requested data
+			 * ISO-639-2 code if the subheading is filled.
+			 *
+			 * If it isn't, show first language
+			 */
+			if (langEntry[lang].subheading.isEmpty())
+				lang = FIRST_LANG;
+			else if (lang != FIRST_LANG)
+				return langEntry[lang].subheading;
+		}
+
+		QHashIterator<QString, DvbEpgLangEntry> i(langEntry);
+		bool first = true;
+
+		while (i.hasNext()) {
+			i.next();
+
+			QString code = i.key();
+			DvbEpgLangEntry entry = i.value();
+
+			if (!entry.subheading.isEmpty()) {
+				if (first)
+					first = false;
+				else
+					s += "/";
+
+				if (langEntry.size() > 1 && (lang != FIRST_LANG && code != FIRST_LANG)) {
+					s += code;
+					s += ": ";
+				}
+				s += entry.subheading;
+			}
+
+			if (lang == FIRST_LANG)
+				break;
+		}
+		return s;
+	}
+
+	QString details(QString lang = QString()) const {
+		QString s;
+
+		if (!lang.isEmpty()) {
+			/*
+			 * Only return the user requested data
+			 * ISO-639-2 code if the details are filled.
+			 *
+			 * If it isn't, show first language
+			 */
+			if (langEntry[lang].details.isEmpty())
+				lang = FIRST_LANG;
+			else if (lang != FIRST_LANG)
+				return langEntry[lang].details;
+		}
+
+		QHashIterator<QString, DvbEpgLangEntry> i(langEntry);
+		bool first = true;
+
+		while (i.hasNext()) {
+			i.next();
+
+			QString code = i.key();
+			DvbEpgLangEntry entry = i.value();
+
+			if (!entry.details.isEmpty()) {
+				if (first)
+					first = false;
+				else
+					s += "\n\n";
+
+				if (langEntry.size() > 1 && (lang != FIRST_LANG && code != FIRST_LANG)) {
+					s += code;
+					s += ": ";
+				}
+				s += entry.details;
+			}
+
+			if (lang == FIRST_LANG)
+				break;
+		}
+		return s;
+	}
+
 	// Check only the user-visible elements
 	bool operator==(const DvbEpgEntry &other) const
 	{
@@ -65,16 +208,31 @@ public:
 			return false;
 		if (duration != other.duration)
 			return false;
-		if (title != other.title)
-			return false;
-		if (subheading != other.subheading)
-			return false;
-		if (details != other.details)
-			return false;
 		if (content != other.content)
 			return false;
-		if (parental != other.parental)
-			return false;
+
+		QHashIterator<QString, DvbEpgLangEntry> i(langEntry);
+		while (i.hasNext()) {
+			i.next();
+
+			QString code = i.key();
+
+			if (!other.langEntry.contains(code))
+				return false;
+
+			DvbEpgLangEntry thisEntry = i.value();
+			DvbEpgLangEntry otherEntry = other.langEntry[code];
+
+			if (thisEntry.title != otherEntry.title)
+				return false;
+			if (thisEntry.subheading != otherEntry.subheading)
+				return false;
+			if (thisEntry.details != otherEntry.details)
+				return false;
+
+			// If first language matches, assume entries are identical
+			return true;
+		}
 
 		return true;
 	}
@@ -129,6 +287,7 @@ signals:
 	void entryRemoved(const DvbSharedEpgEntry &entry);
 	void epgChannelAdded(const DvbSharedChannel &channel);
 	void epgChannelRemoved(const DvbSharedChannel &channel);
+	void languageAdded(const QString lang);
 
 private slots:
 	void channelAboutToBeUpdated(const DvbSharedChannel &channel);
