@@ -40,6 +40,7 @@ class DvbLiveView;
 class DvbRecordingModel;
 class DvbScanData;
 class MediaWidget;
+class XmlTv;
 
 class DvbManager : public QObject
 {
@@ -127,6 +128,7 @@ public:
 
 	QString getRecordingFolder() const;
 	QString getTimeShiftFolder() const;
+	QString getXmltvFileName() const;
 	QString getNamingFormat() const;
 	QString getRecordingRegex() const;
 	QStringList getRecordingRegexList() const;
@@ -136,9 +138,11 @@ public:
 	int getEndMargin() const; // seconds
 	bool override6937Charset() const;
 	bool createInfoFile() const;
+	bool disableEpg() const;
 	bool isScanWhenIdle() const;
 	void setRecordingFolder(const QString &path);
 	void setTimeShiftFolder(const QString &path);
+	void setXmltvFileName(const QString &path);
 	void setNamingFormat(const QString namingFormat);
 	void setRecordingRegex(const QString regex);
 	void setRecordingRegexList(const QStringList regexList);
@@ -152,6 +156,7 @@ public:
 	void setEndMargin(int endMargin); // seconds
 	void setOverride6937Charset(bool override);
 	void setCreateInfoFile(bool createInfoFile);
+	void setDisableEpg(bool disableEpg);
 	void setScanWhenIdle(bool scanWhenIdle);
 	void writeDeviceConfigs();
 
@@ -177,6 +182,7 @@ private:
 	DvbChannelModel *channelModel;
 	QTreeView *channelView;
 	DvbEpgModel *epgModel;
+	XmlTv *xmlTv;
 	DvbLiveView *liveView;
 	DvbRecordingModel *recordingModel;
 	bool reacquireDevice;
