@@ -20,6 +20,8 @@
 
 #include "../log.h"
 
+#include <errno.h>
+
 #include <QCoreApplication>
 #include <QDataStream>
 #include <QDir>
@@ -473,7 +475,7 @@ DvbSharedRecording DvbRecordingModel::getLeastImportant(QList<DvbSharedRecording
 	DvbSharedRecording leastImportant = recList.value(0);
 	foreach(DvbSharedRecording listRec, recList)
 	{
-		qCDebug(logDvb, "name and priority %s %s", qPrintable(listRec->name), qPrintable(listRec->priority));
+		qCDebug(logDvb, "name and priority %s %d", qPrintable(listRec->name), listRec->priority);
 		if (listRec->priority < leastImportant->priority) {
 			leastImportant = listRec;
 		}
@@ -789,7 +791,7 @@ bool DvbRecordingFile::start(DvbRecording &recording)
 		filename = filename.replace("%channel", recording.channel->name);
 		filename = filename.replace("%title", QString(recording.name));
 		filename = filename.replace(QLatin1Char('/'), QLatin1Char('_'));
-		if (filename == "") {
+		if (filename.isEmpty()) {
 			filename = QString(recording.name);
 		}
 
