@@ -18,11 +18,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include <KLocalizedString>
-#include <QDebug>
-#if QT_VERSION < 0x050500
-# define qInfo qDebug
-#endif
+#include "../log.h"
 
 #include <KConfigGroup>
 #include <QAction>
@@ -233,7 +229,7 @@ DvbRecordingTableModel::~DvbRecordingTableModel()
 void DvbRecordingTableModel::setRecordingModel(DvbRecordingModel *recordingModel_)
 {
 	if (recordingModel != NULL) {
-		qWarning("Recording model already set");
+		qCWarning(logDvb, "Recording model already set");
 		return;
 	}
 
