@@ -30,6 +30,7 @@
 #include <QContextMenuEvent>
 #include <QDialogButtonBox>
 #include <QDBusInterface>
+#include <QEvent>
 #include <QFileDialog>
 #include <QLabel>
 #include <QMenu>
@@ -776,9 +777,6 @@ void MediaWidget::setVolume(int volume)
 
 void MediaWidget::setVolumeUnderMouse(int volume)
 {
-	if (!backend->underMouse())
-		return;
-
 	if (volume == 100 || !volume)
 		osdWidget->showText(i18nc("osd", "Volume: %1%", volume), 1500);
 	else
@@ -1312,22 +1310,41 @@ void MediaWidget::dropEvent(QDropEvent *event)
 	}
 }
 
+bool MediaWidget::event(QEvent *event)
+{
+	switch (event->type()) {
+	case QEvent::ShortcutOverride:
+		{
+		QKeyEvent *keyEvent = static_cast<QKeyEvent *>(event);
+		int key = keyEvent->key();
+
+		if (backend->hasDvdMenu()) {
+			switch (key){
+			case Qt::Key_Return:
+			case Qt::Key_Up:
+			case Qt::Key_Down:
+			case Qt::Key_Left:
+			case Qt::Key_Right:
+				backend->dvdNavigate(key);
+				event->accept();
+				return true;
+			}
+		}
+		break;
+		}
+	default:
+		break;
+	}
+
+	return QWidget::event(event);
+}
+
 void MediaWidget::keyPressEvent(QKeyEvent *event)
 {
 	int key = event->key();
 
-	if (backend->hasDvdMenu()) {
-		switch (key){
-		case Qt::Key_Return:
-		case Qt::Key_Up:
-		case Qt::Key_Down:
-		case Qt::Key_Left:
-		case Qt::Key_Right:
-			backend->dvdNavigate(key);
-		}
-	}
-
 	if ((key >= Qt::Key_0) && (key <= Qt::Key_9)) {
+		event->accept();
 		emit osdKeyPressed(key);
 	} else {
 		QWidget::keyPressEvent(event);
@@ -1342,15 +1359,10 @@ void MediaWidget::resizeEvent(QResizeEvent *event)
 
 void MediaWidget::wheelEvent(QWheelEvent *event)
 {
-	int shortSkipDuration = Configuration::instance()->getShortSkipDuration();
-	int currentTime =
-		(backend->getCurrentTime() - ((25 * shortSkipDuration * event->delta()) / 3));
+	int y = event->delta();
+	int delta = (y < 0) ? -1 : 1;
 
-	if (currentTime < 0) {
-		currentTime = 0;
-	}
-
-	backend->seek(currentTime);
+	setVolumeUnderMouse(getVolume() + delta);
 }
 
 void MediaWidget::playbackFinished()
@@ -1421,8 +1433,12 @@ void MediaWidget::metadataChanged()
 		caption = source->getDefaultCaption();
 	}
 
+	QString osdText = caption;
+	if (backend->hasDvdMenu())
+		osdText += "\nUse keys to navigate at DVD menu";
+
 	if (!caption.isEmpty()) {
-		osdWidget->showText(caption, 2500);
+		osdWidget->showText(osdText, 2500);
 	}
 
 	emit changeCaption(caption);
@@ -1433,17 +1449,6 @@ void MediaWidget::dvdMenuChanged()
 	bool hasDvdMenu = backend->hasDvdMenu();
 
 	menuAction->setEnabled(hasDvdMenu);
-
-	// Disable key left/right for DVD, in order to allow its usage
-	// to navigate at DVD's menu. Unfortunately, libVlc doesn't provide
-	// a way to tell if the device is at the DVB menu.
-	if (hasDvdMenu) {
-		shortSkipBackwardAction->setShortcut(Qt::Key_unknown);
-		shortSkipForwardAction->setShortcut(Qt::Key_unknown);
-	} else {
-		shortSkipBackwardAction->setShortcut(Qt::Key_Left);
-		shortSkipForwardAction->setShortcut(Qt::Key_Right);
-	}
 }
 
 void MediaWidget::titlesChanged()
@@ -1606,3 +1611,12 @@ void SeekSlider::mousePressEvent(QMouseEvent *event)
 		event->buttons() ^ event->button() ^ button, event->modifiers());
 	QSlider::mousePressEvent(&modifiedEvent);
 }
+
+void SeekSlider::wheelEvent(QWheelEvent *event)
+{
+	int delta = (event->delta() < 0) ? -1 : 1;
+	int new_value = value() + delta * maximum() / 100;
+
+	event->accept();
+	setValue(new_value);
+}
