@@ -9,6 +9,14 @@ fi
 # not for production use
 
 sourcedir=$(pwd)
-rm -fr install
-cmake -DCMAKE_BUILD_TYPE=Debug -DCMAKE_INSTALL_PREFIX=$sourcedir/install -DSTRICT_BUILD=1 . $sourcedir
+
+cd ..
+
+rm -rf kaffeine_build
+git new-workdir $sourcedir kaffeine_build
+cd kaffeine_build
+
+rm -fr $sourcedir/install
+cmake -DCMAKE_BUILD_TYPE=Debug -DCMAKE_INSTALL_PREFIX=$sourcedir/install -DSTRICT_BUILD=1 .
+make
 make install
